Reahl
=====

Reahl comprises a number of projects that help with the development 
of interactive web applications. 

Reahl-web is a web application framework that allows a programmer to work
in terms of useful abstractions—using a single programming language.

The details of how those abstractions are implemented using several
different web technologies are hidden and dealt with for the
programmer.

Reahl-component provides infrastructure for components in any 
application that can also have their own database schemas, configuration, 
internationalisation and more.

The other projects support development of (mostly web) applications, 
regardless of which web framework is used.

Although all the Reahl components reside in one source code tree, some are 
licensed LGPL and others AGPL (see the relevant licenses in each subdirectory).

More details at our website: [Reahl - the Python-only web framework](http://www.reahl.org)

SPDX-License-Identifier: LGPL-3.0 AND AGPL-3.0
